ManipulaPy.kinematics.SerialManipulator
=======================================

.. currentmodule:: ManipulaPy.kinematics

.. autoclass:: SerialManipulator

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SerialManipulator.__init__
      ~SerialManipulator.end_effector_pose
      ~SerialManipulator.end_effector_velocity
      ~SerialManipulator.forward_kinematics
      ~SerialManipulator.iterative_inverse_kinematics
      ~SerialManipulator.jacobian
      ~SerialManipulator.joint_velocity
      ~SerialManipulator.update_state
   
   

   
   
   